==> haskell-wai-3.2.4-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-ANZD32r1nfA59aypXbDlil
key:                  wai-3.2.4-ANZD32r1nfA59aypXbDlil
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  3839d8c04a2a39afaa136c5998a99863
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-ANZD32r1nfA59aypXbDlil
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    http-types-0.12.4-1L1OgfMGc2W7Nfzsv4RpMF
    network-3.1.4.0-9GJKuf6EY6MAL0cwpbhHGu text-1.2.5.0
    vault-0.3.1.5-9gIJSvY5CgU3LwMjycX5Kq

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.4-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai
version:              3.2.4
visibility:           public
id:                   wai-3.2.4-D36lDqHeOiN8tj0bmewMtj
key:                  wai-3.2.4-D36lDqHeOiN8tj0bmewMtj
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             https://github.com/yesodweb/wai
synopsis:             Web Application Interface.
description:
    Provides a common protocol for communication between web applications and web servers.

    API docs and the README are available at <http://www.stackage.org/package/wai>.

category:             Web
abi:                  6ca9f7b437a9fb7be971a3ca319c3f18
exposed:              True
exposed-modules:      Network.Wai Network.Wai.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-3.2.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-3.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai
hs-libraries:         HSwai-3.2.4-D36lDqHeOiN8tj0bmewMtj
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    http-types-0.12.4-9Ur1ShtqVpgp5ryNgXxt8
    network-3.1.4.0-JL8MfxNaZmuAIivQBcxkBq text-1.2.5.0
    vault-0.3.1.5-HqV7RZWWbuN7yNYv2RT3ST

haddock-interfaces:   /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html:         /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
